/*
Reflexion

Copyright (C) 2012 Observatoire de Paris-Meudon
 
Auteur : Benjamin Mollier
Conversion en Javascript : Damien Guillaume

Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier conformément aux dispositions de la Licence Publique Générale GNU, telle que publiée par la Free Software Foundation ; version 2 de la licence, ou encore (à votre choix) toute version ultérieure.

Ce programme est distribué dans l'espoir qu'il sera utile, mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de COMMERCIALISATION ou D'ADAPTATION A UN OBJET PARTICULIER. Pour plus de détail, voir la Licence Publique Générale GNU .

Vous devez avoir reçu un exemplaire de la Licence Publique Générale GNU en même temps que ce programme ; si ce n'est pas le cas, écrivez à la Free Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, Etats-Unis.
*/

/**
 * Algorithme de simulation pour SimuApplet.
 * Simule les rayons réflechis et réfractés, issus d'un rayon incident sur un dioptre plan.
 */

new Reflexion();

//----- I. Constructeur de la classe, avec la définition des paramètres de simulation et des options d'affichage.
function Reflexion() {
//----- Variable globales
        // - - - I.1 Coordonnées des rayons incidents et réfléchis (x1,y1) et réfracté (x2,y2) - - - -
            this.x1 = 0.;
            this.y1 = 0.;
            this.s = 0.;
    
        // - - - I.2 Pas pour tracés les rayons - - - 
            this.ds = 0.1;
    
        // - - - I.3 Angles réfléchi et réfracté - - -
            this.r1 = 0.;
            this.i1 = 0.;
    
    this.applet = new SimuApplet(this);
    this.applet.appletDoc('reflexion_doc.xml');
    this.applet.setDelaiIterations(Math.round(this.ds * 100));
}

	//----- II. Calcul des rayons
		// - - - II.1 Calcul live (utilisé avec affichage "plotlive") - - - - 
			// - 2.1.1 Initialisation -
Reflexion.prototype.initCalculLive = function(lin) {
    // - 2.1.1.1 Chargement des variables d'entrée -
    this.i1 = lin.lireDouble('i1');
    
    // - 2.1.1.2 Initialisation des coordonnées -
    this.s  =  8;
    this.x1 = -this.s * Math.sin(this.i1 / 180. * Math.PI);
    this.y1 =  this.s * Math.cos(this.i1 / 180. * Math.PI);

    // - 2.1.1.3 Calcul des angles réfléchi et réfracté
    this.r1 = -this.i1;
}

// - 3.1.2 Calcul de l'abscisse curviligne s à s+ds
Reflexion.prototype.calculLive = function() {
    var out;
    
    out = new ListeValeurs();
    if (Math.abs(this.i1) > 90.) return null; 
    
    
    if (this.s > 0)
    {
        this.s -= this.ds;
        this.x1 = -this.s * Math.sin(this.i1 / 180. * Math.PI);
        this.y1 =  this.s * Math.cos(this.i1 / 180. * Math.PI);

    }
    else if (this.s <= 0 && this.s > -8)
    {
    
        this.s -=  this.ds;
        this.x1 =  this.s * Math.sin(this.r1 / 180. * Math.PI);
        this.y1 = -this.s * Math.cos(this.r1 / 180. * Math.PI);
                            
    
    }
    else
        return null; 


    out.ajouterDouble('x1', this.x1);
    out.ajouterDouble('y1', this.y1);
    out.ajouterDouble('i1', this.i1);
    out.ajouterDouble('r1', this.r1);
    
    return out;
}

    // - - - III.2 Calcul complet d'un coup (utilisé avec les affichages "plot" et "tableau") - - - - 
Reflexion.prototype.calcul = function(lin) {
    var out;
    
    this.i1 = lin.lireDouble('i1');
    
    out = new ListeValeurs();
    
    for (this.i1 = 0; this.i1 <= 90 ; this.i1 = this.i1 + 0.1)
    {
        this.r1 = -this.i1;
        
        out.ajouterDouble('x1', this.x1);
        out.ajouterDouble('y1', this.y1);
        out.ajouterDouble('i1', this.i1);
        out.ajouterDouble('r1', this.r1);
        
    }
    return out;
}
